#[non_exhaustive]pub enum Error {
NotFound {
path: PathBuf,
},
Io {
path: PathBuf,
source: Error,
},
UnknownExtension {
path: PathBuf,
},
FeatureDisabled {
format: Format,
feature: &'static str,
},
Parse {
origin: Option<PathBuf>,
format: Format,
message: String,
},
Deserialize(Error),
Defaults(Error),
Watch(Error),
}Expand description
All errors that can occur while loading or watching configuration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
A required configuration file does not exist.
Io
Reading a configuration file failed for I/O reasons other than absence.
UnknownExtension
The file extension does not map to any known configuration format.
FeatureDisabled
The format is recognized but its cargo feature is not enabled.
Fields
Parse
The content is not valid for its format.
Fields
Deserialize(Error)
The merged configuration does not match the target type.
Defaults(Error)
Serializing the defaults layer failed.
Watch(Error)
Setting up the file watcher failed.